==> openshift-client-4.13.2-sources.jar: io/fabric8/openshift/client/handlers/ClusterServiceVersionHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.ClusterServiceVersionOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersion;
import io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class ClusterServiceVersionHandler implements ResourceHandler<ClusterServiceVersion, ClusterServiceVersionBuilder> {

  @Override
  public String getKind() {
    return ClusterServiceVersion.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "operators.coreos.com/v1alpha1";
    }

  @Override
  public ClusterServiceVersion create(OkHttpClient client, Config config, String namespace, ClusterServiceVersion item) {
    return new ClusterServiceVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public ClusterServiceVersion replace(OkHttpClient client, Config config, String namespace, ClusterServiceVersion item) {
    return new ClusterServiceVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public ClusterServiceVersion reload(OkHttpClient client, Config config, String namespace, ClusterServiceVersion item) {
    return new ClusterServiceVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public ClusterServiceVersionBuilder edit(ClusterServiceVersion item) {
    return new ClusterServiceVersionBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, ClusterServiceVersion item) {
    return new ClusterServiceVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterServiceVersion item, Watcher<ClusterServiceVersion> watcher) {
    return new ClusterServiceVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterServiceVersion item, String resourceVersion, Watcher<ClusterServiceVersion> watcher) {
    return new ClusterServiceVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterServiceVersion item, ListOptions options, Watcher<ClusterServiceVersion> watcher) {
  return new ClusterServiceVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public ClusterServiceVersion waitUntilReady(OkHttpClient client, Config config, String namespace, ClusterServiceVersion item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ClusterServiceVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public ClusterServiceVersion waitUntilCondition(OkHttpClient client, Config config, String namespace, ClusterServiceVersion item, Predicate<ClusterServiceVersion> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ClusterServiceVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> openshift-client-5.2.1-sources.jar: io/fabric8/openshift/client/handlers/ClusterServiceVersionHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.ClusterServiceVersionOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersion;
import io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class ClusterServiceVersionHandler implements ResourceHandler<ClusterServiceVersion, ClusterServiceVersionBuilder> {

  @Override
  public String getKind() {
    return ClusterServiceVersion.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "operators.coreos.com/v1alpha1";
    }

  @Override
  public ClusterServiceVersion create(OkHttpClient client, Config config, String namespace, ClusterServiceVersion item, boolean dryRun) {
    return new ClusterServiceVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public ClusterServiceVersion replace(OkHttpClient client, Config config, String namespace, ClusterServiceVersion item, boolean dryRun) {
    return new ClusterServiceVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public ClusterServiceVersion reload(OkHttpClient client, Config config, String namespace, ClusterServiceVersion item) {
    return new ClusterServiceVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public ClusterServiceVersionBuilder edit(ClusterServiceVersion item) {
    return new ClusterServiceVersionBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, ClusterServiceVersion item, boolean dryRun) {
    return new ClusterServiceVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterServiceVersion item, Watcher<ClusterServiceVersion> watcher) {
    return new ClusterServiceVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterServiceVersion item, String resourceVersion, Watcher<ClusterServiceVersion> watcher) {
    return new ClusterServiceVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterServiceVersion item, ListOptions options, Watcher<ClusterServiceVersion> watcher) {
  return new ClusterServiceVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public ClusterServiceVersion waitUntilReady(OkHttpClient client, Config config, String namespace, ClusterServiceVersion item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ClusterServiceVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public ClusterServiceVersion waitUntilCondition(OkHttpClient client, Config config, String namespace, ClusterServiceVersion item, Predicate<ClusterServiceVersion> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ClusterServiceVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
